require 'just/retry'

describe "Just::retry" do

  it "The block is only called once if it succeeds" do
    object = Object.new
    object.should_receive(:ping).once.and_return(:success)
    expect {
      Just::retry do
        object.ping
      end
    }.not_to raise_error(Exception)
  end

  it "The block is called twice by default if it fails" do
    object = Object.new
    object.should_receive(:ping).twice { raise StandardError }
    expect {
      Just::retry do
        object.ping
      end
    }.to raise_error(StandardError)
  end

  it "The block is called n times when a try count is specified" do
    object = Object.new
    n = 5
    object.should_receive(:ping).exactly(n).times { raise StandardError }
    expect {
      Just::retry tries: n do
        object.ping
      end
    }.to raise_error(StandardError)
  end

  it "Unexpected exceptions are reraised" do
    object = Object.new
    object.should_receive(:ping).once { raise StandardError }
    expect {
      Just::retry on: IOError do
        object.ping
      end
    }.to raise_error(StandardError)
  end

  it "sleep is called if it's provided" do
    object = Object.new
    object.should_receive(:ping).twice { raise StandardError }
    Just.stub!(:sleep)
    Just.should_receive(:sleep).once.with(30)
    expect {
      Just::retry delay: 30 do
        object.ping
      end
    }.to raise_error(StandardError)
  end

  it "the retry is logged if a log is provided" do
    object = Object.new
    object.should_receive(:ping).twice { raise StandardError }
    logger = Object.new
    logger.should_receive(:error).with(any_args)
    logger.should_receive(:debug).with(any_args)
    expect {
      Just::retry logger: logger do
        object.ping
      end
    }.to raise_error(StandardError)
  end
end
